@@ -12,46 +12,40 @@ from .renderer import RendererHTML
 from .utils import AttrDict
 
 
-config = AttrDict(
+_PRESETS = AttrDict(
     {
-        "default": presets.default.presets,
-        "zero": presets.zero.presets,
-        "commonmark": presets.commonmark.presets,
+        "default": presets.default.make(),
+        "zero": presets.zero.make(),
+        "commonmark": presets.commonmark.make(),
     }
 )
 
 
 class MarkdownIt:
     def __init__(
-        self,
-        presetName: Union[str, AttrDict] = "commonmark",
-        options=None,
-        renderer=None,
+        self, config: Union[str, AttrDict] = "commonmark", renderer_cls=RendererHTML
     ):
-        """Main class
+        """Main parser class
 
-        :param presetName: name of configuration to load or a pre-defined one
-        :param options: [description], defaults to None
+        :param config: name of configuration to load or a pre-defined dictionary
+        :param renderer_cls: the class to load as the renderer:
+            ``self.renderer = renderer_cls(self)
         """
-        options = options or {}
-        if not options:
-            if not isinstance(presetName, str):
-                options = presetName or {}
-                presetName = "default"
-
         self.inline = ParserInline()
         self.block = ParserBlock()
         self.core = ParserCore()
-        self.renderer = RendererHTML() if renderer is None else renderer
-        # var LinkifyIt    = require('linkify-it')
-        # self.linkify = LinkifyIt()  # TODO maybe see https://github.com/Suor/autolink
+        self.renderer = renderer_cls(self)
 
         self.utils = utils
         self.helpers = helpers
         self.options = {}
-        self.configure(presetName)
-        if options:
-            self.set(options)
+        self.configure(config)
+
+        # var LinkifyIt    = require('linkify-it')
+        # self.linkify = LinkifyIt()  # TODO maybe see https://github.com/Suor/autolink
+
+    def __repr__(self):
+        return f"{self.__class__.__module__}.{self.__class__.__name__}()"
 
     def __getitem__(self, name):
         return {
@@ -83,7 +77,7 @@ class MarkdownIt:
         """
         if isinstance(presets, str):
             presetName = presets
-            presets = config.get(presetName, None)
+            presets = _PRESETS.get(presetName, None)
             if not presets:
                 raise KeyError(
                     'Wrong `markdown-it` preset "' + presetName + '", check name'
@@ -106,6 +100,15 @@ class MarkdownIt:
 
         return self
 
+    def get_all_rules(self) -> Dict[str, List[str]]:
+        """Return the names of all active rules."""
+        rules = {
+            chain: self[chain].ruler.get_all_rules()
+            for chain in ["core", "block", "inline"]
+        }
+        rules["inline2"] = self.inline.ruler2.get_all_rules()
+        return rules
+
     def get_active_rules(self) -> Dict[str, List[str]]:
         """Return the names of all active rules."""
         rules = {
@@ -189,7 +192,7 @@ class MarkdownIt:
         if self.renderer.__output__ == fmt:
             self.renderer.rules[name] = function.__get__(self.renderer)
 
-    def use(self, plugin: Callable, *params) -> "MarkdownIt":
+    def use(self, plugin: Callable, *params, **options) -> "MarkdownIt":
         """Load specified plugin with given params into current parser instance. (chainable)
 
         It's just a sugar to call `plugin(md, params)` with curring.
@@ -201,7 +204,7 @@ class MarkdownIt:
             md = MarkdownIt().use(plugin, 'foo_replace', 'text', func)
 
         """
-        plugin(self, *params)
+        plugin(self, *params, **options)
         return self
 
     def parse(self, src: str, env: Optional[AttrDict] = None) -> List[Token]:
